==> jc-1.4.0.tar.gz: java/io/DeleteFileHelper.h <==
// final class java.io.DeleteFileHelper

// class file dependencies
// @dep_class 1609c024a70c663b java_io_DeleteFileHelper
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_java_io_DeleteFileHelper_H_
#define _JC_java_io_DeleteFileHelper_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_java_io_DeleteFileHelper$sub_refs	_jc_java_io_DeleteFileHelper$sub_refs;
typedef struct _jc_java_io_DeleteFileHelper$sub_nonrefs	_jc_java_io_DeleteFileHelper$sub_nonrefs;
typedef struct _jc_java_io_DeleteFileHelper$refs	_jc_java_io_DeleteFileHelper$refs;
typedef struct _jc_java_io_DeleteFileHelper$nonrefs	_jc_java_io_DeleteFileHelper$nonrefs;
typedef struct _jc_java_io_DeleteFileHelper$object	_jc_java_io_DeleteFileHelper$object;

typedef struct _jc_java_io_DeleteFileHelper$fields_struct	_jc_java_io_DeleteFileHelper$fields_struct;
typedef const struct _jc_java_io_DeleteFileHelper$vmethods	_jc_java_io_DeleteFileHelper$vmethods;
typedef const struct _jc_java_io_DeleteFileHelper$vtable	_jc_java_io_DeleteFileHelper$vtable;
typedef const struct _jc_java_io_DeleteFileHelper$vtype	_jc_java_io_DeleteFileHelper$vtype;

// Class fields structure
struct _jc_java_io_DeleteFileHelper$fields_struct {
	struct _jc_java_util_ArrayList$object	*filesToDelete;
};
extern _jc_java_io_DeleteFileHelper$fields_struct _jc_java_io_DeleteFileHelper$class_fields;

// Constructors
extern void _jc_java_io_DeleteFileHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_DeleteFileHelper$object *);

// Virtual methods
extern void _jc_java_io_DeleteFileHelper$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_io_DeleteFileHelper$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_DeleteFileHelper$method_info$run$8b940e4957c86ebf;

// Static methods
extern void _jc_java_io_DeleteFileHelper$method$add$e602edfd2c61cb7d(_jc_env *, struct _jc_java_io_File$object *);
extern void _jc_java_io_DeleteFileHelper$method$deleteFiles$b0f98ea7e3adabda(_jc_env *);

// Virtual methods structure
struct _jc_java_io_DeleteFileHelper$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_io_DeleteFileHelper$object *);
};

// Vtable
struct _jc_java_io_DeleteFileHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_java_io_DeleteFileHelper$vmethods	java_io_DeleteFileHelper;
};

// Vtype
struct _jc_java_io_DeleteFileHelper$vtype {
	_jc_type			type;
	_jc_java_io_DeleteFileHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_DeleteFileHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_DeleteFileHelper$refs {
    _jc_java_io_DeleteFileHelper$sub_refs	java_io_DeleteFileHelper;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_DeleteFileHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_DeleteFileHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_java_io_DeleteFileHelper$sub_nonrefs	java_io_DeleteFileHelper;
};

// Object instance structure
struct _jc_java_io_DeleteFileHelper$object {
	_jc_java_io_DeleteFileHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_DeleteFileHelper$vtype	*vtype;
	_jc_java_io_DeleteFileHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_DeleteFileHelper$vtype _jc_java_io_DeleteFileHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_DeleteFileHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_DeleteFileHelper$class_object;

#endif	/* _JC_java_io_DeleteFileHelper_H_ */

==> jc-1.4.6.tar.gz: java/io/DeleteFileHelper.h <==
// final class java.io.DeleteFileHelper

// class file dependencies
// @dep_class 1609c024a70c663b java_io_DeleteFileHelper
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_java_io_DeleteFileHelper_H_
#define _JC_java_io_DeleteFileHelper_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_java_io_DeleteFileHelper$sub_refs	_jc_java_io_DeleteFileHelper$sub_refs;
typedef struct _jc_java_io_DeleteFileHelper$sub_nonrefs	_jc_java_io_DeleteFileHelper$sub_nonrefs;
typedef struct _jc_java_io_DeleteFileHelper$refs	_jc_java_io_DeleteFileHelper$refs;
typedef struct _jc_java_io_DeleteFileHelper$nonrefs	_jc_java_io_DeleteFileHelper$nonrefs;
typedef struct _jc_java_io_DeleteFileHelper$object	_jc_java_io_DeleteFileHelper$object;

typedef struct _jc_java_io_DeleteFileHelper$fields_struct	_jc_java_io_DeleteFileHelper$fields_struct;
typedef const struct _jc_java_io_DeleteFileHelper$vmethods	_jc_java_io_DeleteFileHelper$vmethods;
typedef const struct _jc_java_io_DeleteFileHelper$vtable	_jc_java_io_DeleteFileHelper$vtable;
typedef const struct _jc_java_io_DeleteFileHelper$vtype	_jc_java_io_DeleteFileHelper$vtype;

// Class fields structure
struct _jc_java_io_DeleteFileHelper$fields_struct {
	struct _jc_java_util_ArrayList$object	*filesToDelete;
};
extern _jc_java_io_DeleteFileHelper$fields_struct _jc_java_io_DeleteFileHelper$class_fields;

// Constructors
extern void _jc_java_io_DeleteFileHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_DeleteFileHelper$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_DeleteFileHelper$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_io_DeleteFileHelper$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_DeleteFileHelper$method_info$run$8b940e4957c86ebf;

// Static methods
extern void _jc_java_io_DeleteFileHelper$method$add$e602edfd2c61cb7d(_jc_env *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_DeleteFileHelper$method$deleteFiles$b0f98ea7e3adabda(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_DeleteFileHelper$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_io_DeleteFileHelper$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_DeleteFileHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_java_io_DeleteFileHelper$vmethods	java_io_DeleteFileHelper;
};

// Vtype
struct _jc_java_io_DeleteFileHelper$vtype {
	_jc_type			type;
	_jc_java_io_DeleteFileHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_DeleteFileHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_DeleteFileHelper$refs {
    _jc_java_io_DeleteFileHelper$sub_refs	java_io_DeleteFileHelper;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_DeleteFileHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_DeleteFileHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_java_io_DeleteFileHelper$sub_nonrefs	java_io_DeleteFileHelper;
};

// Object instance structure
struct _jc_java_io_DeleteFileHelper$object {
	_jc_java_io_DeleteFileHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_DeleteFileHelper$vtype	*vtype;
	_jc_java_io_DeleteFileHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_DeleteFileHelper$vtype _jc_java_io_DeleteFileHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_DeleteFileHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_DeleteFileHelper$class_object;

#endif	/* _JC_java_io_DeleteFileHelper_H_ */
